@@ -90,7 +90,7 @@ def imports(enums_module: str) -> str:
         "import os",
         "import typing as T",
         "from enum import Enum",
-        "from datetime import datetime, date, timedelta",
+        "from datetime import datetime, date, timedelta, time",
         "from uuid import UUID",
         "from decimal import Decimal",
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
